@@ -1,20 +1,18 @@
 #' Prepare data for a trajectory plot
 #'
 #' @param data A data frame. Requirements:
-#' * The structure must be like [market_share].
+#' * The structure must be like [market_share_demo].
 #' * The following columns must have a single value: `sector`, `technology`,
 #' `region`, `scenario_source`.
 #' * (Optional) If present, the column `label` is used for data labels.
-#' @template convert_label
-#' @templateVar fun qplot_trajectory
-#' @templateVar value recode_metric_trajectory
+#' @param convert_label `r convert_label_docs("qplot_trajectory", "recode_metric_trajectory")`
 #' @param span_5yr Logical. Use `TRUE` to restrict the time span to 5 years from
 #'   the start year (the default behavior of `qplot_trajectory()`), or use
 #'   `FALSE` to impose no restriction.
 #' @param value_col Character. Name of the column to be used as a value to be
 #'   plotted.
 #'
-#' @seealso [market_share].
+#' @seealso [market_share_demo].
 #'
 #' @return A data-frame ready to be plotted using `plot_trajectory()`.
 #' @export
@@ -22,7 +20,7 @@
 #' @examples
 #' # `data` must meet documented "Requirements"
 #' data <- subset(
-#'   market_share,
+#'   market_share_demo,
 #'   sector == "power" &
 #'     technology == "renewablescap" &
 #'     region == "global" &
@@ -66,7 +64,7 @@ check_prep_trajectory <- function(data,
   stopifnot(is.character(value_col))
 
   crucial <- c(common_crucial_market_share_columns(), value_col)
-  hint_if_missing_names(abort_if_missing_names(data, crucial), "market_share")
+  hint_if_missing_names(abort_if_missing_names(data, crucial), "market_share_demo")
   enforce_single_value <- c("sector", "technology", "region", "scenario_source")
   abort_if_multiple(data, enforce_single_value, env = env)
 
